# Fetch Islandora Collections

Command-line tool for downloading collections from Islandora. Its goals are to be ease of use (e.g., all you do is run it and follow the prompts) and flexibility (e.g., via plugins).

Currently only works with single-file content types.

## Requirements

* On the target Islandora instance
  * [Islandora REST](https://github.com/discoverygarden/islandora_rest)
* On the system where the script is run
  * Python 2.7. Will not run on Python 3.

## Installation

1. `git clone https://github.com/mjordan/fetch_islandora_collections.git`
1. `cd fetch_islandora_collections`

## Overview and usage

### Running the script

`python fetch_collection`

Agree to the terms of use, select a collection, specify an output directory, and hit enter. Output will look like this (assuming you specified `output` as your output directory):

```
output/
├── islandora%3A1
│   ├── DC.xml
│   └── OBJ.jpg
├── islandora%3A10
│   ├── DC.xml
│   └── OBJ.jpg
├── islandora%3A9
│   ├── DC.xml
│   └── OBJ.jpg
└── manifest.csv
```

Each Islandora object will be saved in its own subdirectory named after the object's PID; the directory name is encoded to make the `:` in the PID filesystem safe. In the output directory there will be a CSV file named `manifest.csv` listing for each object its PID, content model, and label.

### Plugins

#### Overview

Plugins are simple Python modules that act on the retrived object just after it is saved to disk. Currently, fetch_collection comes with two plugins, one that writes out the manifest file and the other that changes the extension on JPEG files from `.jpe` to `.jpg`.

#### Writing your own plugins

To write your own plugin, add a Python file (must end in `.py`) to the `CollectionFetcherPlugins`. The file must contain an `execute` method that takes the following arguments:

* `dir`: the object's output directory
* `pid`: the object's PID
* `cmodel`: the object's content model, in the form `info:fedora/islandora:sp_basic_image`
* `label`: the object's label

Your plugin doesn't need to be registered; its presence in the `CollectionFetcherPlugins` directory is sufficient.

## Maintainer

* [Mark Jordan](https://github.com/mjordan)

## Development and feedback

* If you discover a bug, or have a use case not documented here, open an issue.
* If you want to open a pull request, open an issue first.
  * By opening a pull request, you agree to placing your contribution into the public domain.

## License

The Unlicense
